@@ -1,2 +1,2 @@
-from .auth import get_wss_url
+from .auth import get_auth_url
 from .common import generate_rfc1123_date
